@@ -1,12 +1,14 @@
+import errno
 import logging
 import os
+from enum import Enum
 from pathlib import Path
 from shutil import make_archive
-from typing import Tuple, Type
+from typing import Tuple, Type, Union
 from zipfile import BadZipFile, ZipFile
 
 from aleph_message.models import MessageType
-from aleph_message.models.program import Encoding
+from aleph_message.models.execution.program import Encoding
 
 from aleph.sdk.conf import settings
 from aleph.sdk.types import GenericMessage
@@ -59,3 +61,34 @@ def get_message_type_value(message_type: Type[GenericMessage]) -> MessageType:
     """Returns the value of the 'type' field of a message type class."""
     type_literal = message_type.__annotations__["type"]
     return type_literal.__args__[0]  # Get the value from a Literal
+
+
+def check_unix_socket_valid(unix_socket_path: str) -> bool:
+    """Check that a unix socket exists at the given path, or raise a FileNotFoundError."""
+    path = Path(unix_socket_path)
+    if not path.exists():
+        raise FileNotFoundError(
+            errno.ENOENT, os.strerror(errno.ENOENT), unix_socket_path
+        )
+    if not path.is_socket():
+        raise FileNotFoundError(
+            errno.ENOTSOCK,
+            os.strerror(errno.ENOENT),
+            unix_socket_path,
+        )
+    return True
+
+
+def enum_as_str(obj: Union[str, Enum]) -> str:
+    """Returns the value of an Enum, or the string itself when passing a string.
+
+    Python 3.11 adds a new formatting of string enums.
+    `str(MyEnum.value)` becomes `MyEnum.value` instead of `value`.
+    """
+    if not isinstance(obj, str):
+        raise TypeError(f"Unsupported enum type: {type(obj)}")
+
+    if isinstance(obj, Enum):
+        return obj.value
+
+    return obj
