@@ -8,7 +8,8 @@ import pytest
 from nacl.signing import VerifyKey
 
 from aleph.sdk.chains.common import get_verification_buffer
-from aleph.sdk.chains.sol import SOLAccount, get_fallback_account
+from aleph.sdk.chains.sol import SOLAccount, get_fallback_account, verify_signature
+from aleph.sdk.exceptions import BadSignatureError
 
 
 @dataclass
@@ -49,7 +50,6 @@ async def test_SOLAccount(solana_account):
     assert type(pubkey) == bytes
     assert len(pubkey) == 32
 
-    # modeled according to https://github.com/aleph-im/pyaleph/blob/master/src/aleph/chains/solana.py
     verify_key = VerifyKey(pubkey)
     verification_buffer = get_verification_buffer(message)
     assert get_verification_buffer(initial_message) == verification_buffer
@@ -60,6 +60,10 @@ async def test_SOLAccount(solana_account):
     assert verif == verification_buffer
     assert message["sender"] == signature["publicKey"]
 
+    pubkey = solana_account.get_public_key()
+    assert type(pubkey) == str
+    assert len(pubkey) == 64
+
 
 @pytest.mark.asyncio
 async def test_decrypt_curve25516(solana_account):
@@ -71,3 +75,47 @@ async def test_decrypt_curve25516(solana_account):
     decrypted = await solana_account.decrypt(encrypted)
     assert type(decrypted) == bytes
     assert content == decrypted
+
+
+@pytest.mark.asyncio
+async def test_verify_signature(solana_account):
+    message = asdict(
+        Message(
+            "SOL",
+            solana_account.get_address(),
+            "POST",
+            "SomeHash",
+        )
+    )
+    await solana_account.sign_message(message)
+    assert message["signature"]
+    raw_signature = json.loads(message["signature"])["signature"]
+    assert type(raw_signature) == str
+
+    verify_signature(raw_signature, message["sender"], get_verification_buffer(message))
+
+    # as bytes
+    verify_signature(
+        base58.b58decode(raw_signature),
+        base58.b58decode(message["sender"]),
+        get_verification_buffer(message).decode("utf-8"),
+    )
+
+
+@pytest.mark.asyncio
+async def test_verify_signature_with_forged_signature(solana_account):
+    message = asdict(
+        Message(
+            "SOL",
+            solana_account.get_address(),
+            "POST",
+            "SomeHash",
+        )
+    )
+    await solana_account.sign_message(message)
+    assert message["signature"]
+    # create forged 64 bit signature from random bytes
+    forged = base58.b58encode(bytes(64)).decode("utf-8")
+
+    with pytest.raises(BadSignatureError):
+        verify_signature(forged, message["sender"], get_verification_buffer(message))
